@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Catalogue.py
-Version : 1.0.3
+Version : 1.0.4
 Author  : Stefano Covino
-Date    : 05/02/2012
+Date    : 07/01/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -16,6 +16,7 @@ History : (05/10/2010) First version.
         : (15/10/2010) Wrong output for SDSS filters.
         : (16/10/2010) Output better suited for skycat.
         : (05/02/2012) Better path management.
+        : (07/01/2013) Better formatting for output.
 
 
 """
@@ -101,7 +102,8 @@ class AstroWiseStandardStars:
             msg = msg + "%10.3f\t%9.3f\t" % (self.r, self.er)
             msg = msg + "%10.3f\t%9.3f\t" % (self.i, self.ei)
             msg = msg + "%10.3f\t%9.3f" % (self.z, self.ez)
-            return msg
+            msgo = "".join(i for i in msg if 0 < ord(i) < 128)
+            return "\t".join(msgo.split())
             
             
         def __cmp__ (self, other):
