@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Fits.py
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 23/05/2010
+Date    : 14/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,18 +13,19 @@ Usage   : to be imported
 Remarks :
 
 History : (23/05/2010) First version.
+        : (14/02/2012) Possibility to read extensions.
 
 """
 
 import pyfits
 import FitsConstants
 
-def GetHeader (fitsfile):
+def GetHeader (fitsfile, ext=0):
     try:
         hdr = pyfits.open(fitsfile)
     except IOError:
         return None,FitsConstants.FitsFileNotFound
-    heder = hdr[0].header
+    heder = hdr[ext].header
     return heder,FitsConstants.FitsHeaderFound
     
 
