@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames.py
-Version : 1.7.0
+Version : 1.7.1
 Author  : Stefano Covino
-Date    : 16/10/2013
+Date    : 16/07/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -35,6 +35,7 @@ History : (27/09/2010) First version.
         : (29/08/2013) Tunable tolerance for triangle match. Do not update RA,DEC if they already exist.
         : (03/09/2013) Better search of catalogue objects.
         : (16/10/2013) Better computation of frame center.
+        : (16/07/2014) Deal with non standard FITS headers.
 """
 
 
@@ -465,7 +466,7 @@ class Astrometry:
             frm[0].scale('float32')
         elif self.FitsFrame.BITPIX == -64:
             frm[0].scale('float64')
-        frm.writeto(nfile,clobber=True)
+        frm.writeto(nfile,clobber=True,output_verify='ignore')
         warnings.resetwarnings() 
         warnings.filterwarnings('always', category=UserWarning, append=True)
 
