@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Math.py
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 05/09/2010
+Date    : 11/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,6 +13,7 @@ Usage   : to be imported
 Remarks :
 
 History : (05/09/2010) First version.
+        : (11/02/2012) Shift distance.
 
 """
 
@@ -22,8 +23,8 @@ from AstroAngleInput import AstroAngleInput
 
 
 class Point:
-    def __init__ (self, coord):
-        self.Coord = coord
+    def __init__ (self, coord, shx=0.0, shy=0.0):
+        self.Coord = [coord[0]+shx,coord[1]+shy]
         
     def PointDist (self, other):
         dist = math.sqrt((self.Coord[0]-other.Coord[0])**2 + (self.Coord[1]-other.Coord[1])**2)
@@ -39,5 +40,8 @@ class Point:
             ang = 90.0 - ang
         return ang
         
+    def ShiftDist (self, other):    
+        return other.Coord[0]-self.Coord[0], other.Coord[1]-self.Coord[1]
+
     def __str__(self):
         return "%g %g" % (self.Coord[0], self.Coord[1])
\ No newline at end of file
