@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Tables
-Version : 1.0.0
+Version : 1.0.1
 Author  : Stefano Covino
-Date    : 08/11/2010
+Date    : 11/02/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -14,9 +14,10 @@ Usage   : to be imported
 Remarks :
 
 History : (08/11/2010) First version.
+        : (11/02/2013) CleanStr and SkyStr added.
 """
 
 
 
-__all__ = ['FindObjects',]
+__all__ = ['CleanStr', 'FindObjects', 'SkyStr']
 
