@@ -2,10 +2,10 @@
 
 Context : SRP
 Module  : SRPUtil.py
-Version : 1.22.0
+Version : 1.22.1
 Status  : approved
 Author  : Stefano Covino, Nino Cucchiara
-Date    : 11/02/2013
+Date    : 11/03/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 Purpose : Collection of utility functions and classes for SRP.
@@ -46,6 +46,7 @@ History : (29/05/2003) First version.
         : (30/10/2011) Ellipticity added to StarData class.
         : (18/12/2012) Airmass in Daophot and GAIA output.
         : (11/02/2013) Classification added to StarData class.
+        : (11/03/2014) Bug in daophot allstar output.
 """
 
 
@@ -289,7 +290,7 @@ class DAOStarPsfData:
         msg = msg + "%6d\t%10.3f\t%10.3f" % (self.Id, self.X, self.Y)
         msg = msg + "\t%10.2f\t%4d\t%5.1f" % (self.Sky, self.nIt, self.Chi)
         msg = msg + "\t%5.1f\t%8.3f\t%8.3f" % (self.Sharp, self.Mag, self.eMag)
-        msg = msg + "\t%8.3" % (self.Airmass)
+        msg = msg + "\t%8.3f" % (self.Airmass)
         return msg
 
 
