@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.40
+Version : 1.1.46
 Author  : Stefano Covino
-Date    : 25/03/2014
+Date    : 06/08/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -115,6 +115,12 @@ History : (28/09/2010) First named version.
         : (05/02/2014) V. 3.10.13.
         : (06/02/2014) V. 3.10.14 and 3.10.15b1. SRPAstro.FITS management and 3.11.0b1.
         : (25/03/2014) V. 3.11.0.
+        : (19/04/2014) V. 3.11.1b1.
+        : (04/05/2014) V. 3.11.1b2.
+        : (16/07/2014) V. 3.11.1b3.
+        : (21/07/2014) V. 3.11.1b4.
+        : (02/08/2014) V. 3.12.0b1.
+        : (06/08/2014) V. 3.12.0.
 """
 
 
@@ -129,6 +135,6 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.11.0'
+__version__ = '3.12.0'
 
 #
\ No newline at end of file
